export default {
    "message": "Unexpected token {",
    "column": 14,
    "index": 13,
    "lineNumber": 1
}